@@ -763,7 +763,7 @@ main (int    argc,
         ret = gdm_settings_direct_init (state->settings, DATADIR "/gdm/gdm.schemas", "/");
 
         if (!ret) {
-                g_printerr ("Unable to initialize settings");
+                g_printerr ("Unable to initialize settings\n");
                 exit_status = EX_DATAERR;
                 goto out;
         }
@@ -781,7 +781,7 @@ main (int    argc,
         ret = spawn_x_server (state, allow_remote_connections, state->cancellable);
 
         if (!ret) {
-                g_printerr ("Unable to run X server");
+                g_printerr ("Unable to run X server\n");
                 exit_status = EX_SOFTWARE;
                 goto out;
         }
@@ -789,7 +789,7 @@ main (int    argc,
         ret = spawn_bus (state, state->cancellable);
 
         if (!ret) {
-                g_printerr ("Unable to run session message bus");
+                g_printerr ("Unable to run session message bus\n");
                 exit_status = EX_SOFTWARE;
                 goto out;
         }
@@ -797,7 +797,7 @@ main (int    argc,
         ret = register_display (state, state->cancellable);
 
         if (!ret) {
-                g_printerr ("Unable to register display with display manager");
+                g_printerr ("Unable to register display with display manager\n");
                 exit_status = EX_SOFTWARE;
                 goto out;
         }
@@ -805,7 +805,7 @@ main (int    argc,
         ret = spawn_session (state, run_script, state->cancellable);
 
         if (!ret) {
-                g_printerr ("Unable to run session");
+                g_printerr ("Unable to run session\n");
                 exit_status = EX_SOFTWARE;
                 goto out;
         }
